/*
The sensor outputs provided by the library are the raw 16-bit values
obtained by concatenating the 8-bit high and low magnetometer data registers.
They can be converted to units of gauss using the
conversion factors specified in the datasheet for your particular
device and full scale setting (gain).

Example: An LIS3MDL gives a magnetometer X axis reading of 1292 with its
default full scale setting of +/- 4 gauss. The GN specification
in the LIS3MDL datasheet (page 8) states a conversion factor of 6842
LSB/gauss (where LSB means least significant bit) at this FS setting, so the raw
reading of 1292 corresponds to 1292 / 6842 = 0.1888 gauss.

La datasheet : https://www.st.com/resource/en/datasheet/lis3mdl.pdf
*/

#if DOF_9 == 1
#include <LIS3MDL.h>

LIS3MDL mag;

float SetMagnetoSensibility(){
if (MAGNETOMETER_SENSITIVITY == 4){ return 6842; }
else if (MAGNETOMETER_SENSITIVITY == 8){ return 3421; }
else if (MAGNETOMETER_SENSITIVITY == 12){ return 2281; }
else if (MAGNETOMETER_SENSITIVITY == 16){ return 1711; }
else{ Serial.println("Mauvaise sensibilité +/- spécifiée. Valeurs typiques : 4/8/12/16"); }}

float magneto_conversion_factor = SetMagnetoSensibility();

void SetupMagnetometer(){ 
  if (!mag.init()) {
    Serial.println("Failed to detect and initialize magnetometer!");
    while (1); }
  mag.enableDefault();}

void ReadMagneto(){
  mag.read();
  magneto_readings[0] = ((float(mag.m.x)/magneto_conversion_factor) - offsetX) * scaleX;
  magneto_readings[1] = ((float(mag.m.y)/magneto_conversion_factor) - offsetY) * scaleY;
  magneto_readings[2] = ((float(mag.m.z)/magneto_conversion_factor) - offsetZ) * scaleZ;
}
#endif